@@ -8,7 +8,8 @@ import sys
 
 from pprint import pformat
 
-from tornado.options import define, options, parse_command_line
+from tornado.options import define, options
+from tornado.options import parse_command_line, parse_config_file
 
 from celery.bin.base import Command
 
@@ -24,13 +25,13 @@ define("inspect", default=True, help="inspect workers", type=bool)
 define("inspect_timeout", default=1000, type=float,
        help="inspect timeout (in milliseconds)")
 define("auth", default='', type=str,
-       help="regexp  of emails to grant access")
-define("basic_auth", type=str, default=None,
-       help="colon separated user-password to enable basic auth")
+       help="regexp of emails to grant access")
+define("basic_auth", type=str, default=None, multiple=True,
+       help="enable http basic authentication")
 define("url_prefix", type=str, help="base url prefix")
 define("max_tasks", type=int, default=10000,
        help="maximum number of tasks to keep in memory (default 10000)")
-define("db", type=str, default='flower.db', help="flower database file")
+define("db", type=str, default='flower', help="flower database file")
 define("persistent", type=bool, default=False, help="enable persistent mode")
 define("broker_api", type=str, default=None,
        help="inspect broker e.g. http://guest:guest@localhost:15672/api/")
@@ -38,6 +39,8 @@ define("certfile", type=str, default=None, help="path to SSL certificate file")
 define("keyfile", type=str, default=None, help="path to SSL key file")
 define("xheaders", type=bool, default=False,
        help="enable support for the 'X-Real-Ip' and 'X-Scheme' headers.")
+define("auto_refresh", default=True, help="refresh dashboards", type=bool)
+define("cookie_secret", type=str, default=None, help="secure cookie secret")
 
 
 class FlowerCommand(Command):
@@ -45,8 +48,15 @@ class FlowerCommand(Command):
     def run_from_argv(self, prog_name, argv=None, **_kwargs):
         app_settings = settings.APP_SETTINGS
         argv = list(filter(self.flower_option, argv))
+        try:
+            parse_config_file('flowerconfig.py', final=False)
+        except IOError:
+            pass
         parse_command_line([prog_name] + argv)
+
         app_settings['debug'] = options.debug
+        if options.cookie_secret:
+            app_settings['cookie_secret'] = options.cookie_secret
 
         if options.url_prefix:
             prefix = options.url_prefix.strip('/')
@@ -54,6 +64,7 @@ class FlowerCommand(Command):
             app_settings['login_url'] = '/{0}/login'.format(prefix)
             settings.URL_PREFIX = prefix
         settings.CELERY_INSPECT_TIMEOUT = options.inspect_timeout
+        settings.AUTO_REFRESH = options.auto_refresh
 
         if options.debug:
             logging.getLogger().setLevel(logging.DEBUG)
@@ -75,6 +86,8 @@ class FlowerCommand(Command):
                      options.address or 'localhost',
                      options.port)
         logging.info('Broker: %s', self.app.connection().as_uri())
+        logging.debug('Registered tasks: \n%s',
+                      pformat(sorted(self.app.tasks.keys())))
         logging.debug('Settings: %s', pformat(app_settings))
 
         try:
