@@ -61,6 +61,7 @@ class State(threading.Thread):
         try:
             if transport == 'amqp' and self._broker_api:
                 broker = Broker(burl, self._broker_api)
+                broker.queues([])
             elif transport == 'redis':
                 broker = Broker(burl)
         except Exception as e:
@@ -161,4 +162,7 @@ class State(threading.Thread):
 
     @property
     def active_queue_names(self):
-        return set(map(lambda x: x[0]['name'], self._active_queues.values()))
+        queues = set([])
+        for q in self._active_queues.values():
+            queues.update(map(lambda x: x['name'], q))
+        return queues
