@@ -446,7 +446,10 @@ var flower = (function () {
     }
 
     function current_unix_time() {
-        return new Date().getTime() / 1000;
+        var now = new Date();
+        return Date.UTC(now.getUTCFullYear(), now.getUTCMonth(),
+                        now.getUTCDate(),  now.getUTCHours(),
+                        now.getUTCMinutes(), now.getUTCSeconds())/1000;
     }
 
     function url_prefix() {
