@@ -3,6 +3,8 @@ from __future__ import absolute_import
 import base64
 import uuid
 
+from .. import __version__
+
 
 def gen_cookie_secret():
     return base64.b64encode(uuid.uuid4().bytes + uuid.uuid4().bytes)
@@ -11,6 +13,6 @@ def gen_cookie_secret():
 def bugreport():
     try:
         import celery
-        return celery.bugreport()
+        return 'flower   -> %s' % __version__ + celery.bugreport()
     except (ImportError, AttributeError):
         return 'Unknown Celery version'
