@@ -66,7 +66,7 @@ class BaseHandler(tornado.web.RequestHandler):
             try:
                 basic, credentials = auth_header.split()
                 credentials = b64decode(credentials.encode()).decode()
-                if basic != 'Basic' or credentials != basic_auth:
+                if basic != 'Basic' or credentials not in basic_auth:
                     raise tornado.web.HTTPError(401)
             except ValueError:
                 raise tornado.web.HTTPError(401)
@@ -75,15 +75,20 @@ class BaseHandler(tornado.web.RequestHandler):
         if not self.application.auth:
             return True
         user = self.get_secure_cookie('user')
-        if user and re.search(self.application.auth, user):
-            return user
-        else:
-            return
+        if user:
+            if not isinstance(user, str):
+                user = user.decode()
+            if re.search(self.application.auth, user):
+                return user
+        return None
 
     def absolute_url(self, url):
-        base = "{0}://{1}/".format(self.request.protocol, self.request.host)
         if settings.URL_PREFIX:
-            base += settings.URL_PREFIX + '/'
+            base = "{0}://{1}/{2}/".format(self.request.protocol,
+                                           self.request.host,
+                                           settings.URL_PREFIX)
+        else:
+            base = '/'
         aurl = urljoin(base, url[1:] if url.startswith('/') else url)
         aurl = aurl[:-1] if aurl.endswith('/') else aurl
         return aurl
