@@ -22,12 +22,11 @@ class TasksView(BaseHandler):
     @web.authenticated
     def get(self):
         app = self.application
-        limit = self.get_argument('limit', None)
+        limit = self.get_argument('limit', default=None, type=int)
         worker = self.get_argument('worker', None)
         type = self.get_argument('type', None)
         state = self.get_argument('state', None)
 
-        limit = limit and int(limit)
         worker = worker if worker != 'All' else None
         type = type if type != 'All' else None
         state = state if state != 'All' else None
