@@ -7,13 +7,17 @@ from ..models import WorkersModel, WorkerModel
 
 
 class WorkersView(BaseHandler):
+    @web.authenticated
     def get(self):
         app = self.application
-        self.render("workers.html",
-                workers=WorkersModel.get_latest(app).workers)
+        workers = WorkersModel.get_latest(app).workers
+        broker = app.celery_app.connection().as_uri()
+
+        self.render("workers.html", workers=workers, broker=broker)
 
 
 class WorkerView(BaseHandler):
+    @web.authenticated
     def get(self, workername):
         app = self.application
         worker = WorkerModel.get_worker(app, workername)
