@@ -1,10 +1,13 @@
-from urllib import urlencode
+try:
+    from urllib.parse import urlencode
+except ImportError:
+    from urllib import urlencode
 
 import tornado.testing
 
 import celery
 
-from flower.app import Application
+from flower.app import Flower
 from flower.urls import handlers
 from flower.events import Events
 from flower.state import State
@@ -16,8 +19,8 @@ class AsyncHTTPTestCase(tornado.testing.AsyncHTTPTestCase):
         celery_app = celery_app or celery.Celery()
         events = events or Events(celery_app)
         state = state or State(celery_app)
-        self.app = Application(celery_app, events, state,
-                               handlers, **APP_SETTINGS)
+        self.app = Flower(celery_app=celery_app, events=events,
+                          state=state, handlers=handlers, **APP_SETTINGS)
         return self.app
 
     def get(self, url, **kwargs):
